\name{f.analyze.file.summary}
\alias{f.analyze.file.summary}
\title{prints summary of .img file contents}
\description{Prints a summary of the contents of an ANALYZE .img file using
  the associated .hdr header file.}
\usage{f.analyze.file.summary(file)}
\arguments{\item{file}{The location of .img file to be read}}
\value{A print out containing information about the .img file. This includes
    File name, Data Dimension, X dimension, Y dimension, Z dimension, Time dimension, Voxel dimensions, Data type}
\seealso{  \code{\link{f.read.analyze.header}},
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.read.analyze.ts}},
  \code{\link{f.write.analyze}},
  \code{\link{f.read.analyze.volume}},
  \code{\link{f.spectral.summary}},
  \code{\link{f.write.array.to.img.2bytes}},
  \code{\link{f.write.array.to.img.float}},
  \code{\link{f.write.list.to.hdr}},
   \code{\link{f.basic.hdr.list.create}}   }
 \examples{
f.analyze.file.summary(system.file("example.img", package="AnalyzeFMRI"))
}
\keyword{utilities}
\eof
\name{f.analyzeFMRI.gui}
\alias{f.analyzeFMRI.gui}
\title{starts AnalyzeFMRI GUI}
\description{Starts an R/tk interfaced GUI that allows the user to
  explore an fMRI dataset stored in an ANALYZE format file using the
  functions of the AnalyzeFMRI package.
}
\usage{
f.analyzeFMRI.gui()
}
\value{No value is returned
}
\keyword{utilities}
\eof
\name{f.basic.hdr.list.create}
\alias{f.basic.hdr.list.create}
\title{creates basic .hdr list}
\description{Creates a basic list that can be used to write a .hdr file
}
\usage{f.basic.hdr.list.create(mat, file.hdr)
}

\arguments{
  \item{mat}{\code{mat} Array that is to be converted to a .img file}
  \item{file.hdr}{\code{file.hdr} Name of the .hdr file that will be created }
}
\value{Returns a list of all the fields needed to create a .hdr file
  (see the functions code for details).}
\seealso{ 
  \code{\link{f.write.list.to.hdr}},
  \code{\link{f.analyze.file.summary}} 
}
\examples{
a<-array(rnorm(20*30*40*3),dim=c(20,30,40,3))
file<-"temp.hdr"
f.basic.hdr.list.create(a, file)
}
\keyword{utilities}
\eof
\name{f.ica.fmri}
\alias{f.ica.fmri}
\title{Applies Spatial ICA (Independent Component Analysis) to fMRI datasets}
\description{Decomposes an fMRI dataset into a specified number of
  Spatially Independent Components maps and associated time-courses using the FastICA algorithm}
\usage{
f.ica.fmri(file.name, n.comp, norm.col=TRUE, fun="logcosh", maxit=1000,
alg.type="parallel", alpha=1, tol=1e-04, mask.file.name=NULL, slices=NULL)
}
\arguments{
  \item{file.name}{path to fMRI dataset (ANALYZE format .img file) }
  \item{n.comp}{number of components to extract}
  \item{norm.col}{a logical value indicating whether each voxel time
    series should be standardised to have zero mean and unit variance
    before the ICA algorithm is applied (default=TRUE recommended in practice)}
  \item{fun}{the functional form of the G function used in the
    approximation to negentropy (see details)}
  \item{maxit}{maximum number of iterations to perform}
  \item{alg.type}{if \code{alg.typ=="deflation"} the components are
    extracted one at a time (the default).
    if \code{alg.typ=="parallel"} the components are extracted
    simultaneously.}
  \item{alpha}{constant in range [1,2] used in approximation to
    negentropy when \code{fun=="logcosh"}}
  \item{tol}{a positive scalar giving the tolerance at which the
    un-mixing matrix is considered to have converged.}
  \item{mask.file.name}{Optional path to file containing a 0/1 mask for
    the dataset}
  \item{slices}{Optional vector of slices to be included}
}
\details{The fMRI dataset is rearranged into a 2-dimensional data matrix
  X, where the column vectors are voxel time-series. A mask is used to
  specify which voxels are included. If this is not supplied by the user
  then a mask is constructed automatically using a 10\% intensity threshold.

  The data matrix is considered to be a linear combination of
  non-Gaussian (independent) components i.e. X = AS where rows of S
  contain the independent components and A is a linear mixing
  matrix. In short ICA attempts to 'un-mix' the data by estimating an
  un-mixing matrix U where UX = S.

  Under this generative model the measured 'signals' in X will tend to
  be 'more Gaussian' than the source components (in S) due to the Central
  Limit Theorem. Thus, in order to extract the independent
  components/sources we search for an un-mixing matrix U that
  maximizes the non-gaussianity of the sources.

  In FastICA, non-gaussianity is measured using approximations to
  negentropy (J) which are more robust than kurtosis based measures and fast
  to compute.

  The approximation takes the form

  \eqn{J(y)=[E{G(y)}-E{G(v)}]^2} where \eqn{v} is a N(0,1) r.v

  The following choices of G are included as options
  \eqn{G(u)=\frac{1}{\alpha} \log \cosh (\alpha u)} and \eqn{G(u)=-\exp(\frac{-u^2}{2})}

  The FastICA algorithm is used to 'un-mix' the data and recover
  estimates of the mixing matrix A and the source matrix S. Rows of the
  source matrix S represent spatially independent components of the
  dataset (these are arranged spatially in the output). Columns of A
  contain the associated time-courses of the independent components.

  Pre-processing involves removing the mean of each row of the data
  matrix and (optionally) standardizing the columns of the data matrix
  to have zero mean and unit variance.

  All computations are done using C code. This avoids reading the entire
  dataset into R and thus saves memory space.
  
}
\value{A list containing the following components
  
  \item{A}{estimated mixing matrix}
  \item{S}{estimated source matrix that has been rearranged spatially
    i.e. S is a 4-D array and S[,,,i] contains the 3-D map of the ith
    component}
  \item{file}{the name of the data file}
  \item{mask}{the name of the mask file}
}
\references{A. Hyvarinen and E. Oja (2000) Independent Component
  Analysis: Algorithms and Applications, Neural Networks,
  13(4-5):411-430
  
  Beckmann C. (2000) Independent Component Analysis for fMRI. First Year
  D.Phil Report, Dept. of Engineering Science, University of Oxford.}
\author{J L Marchini <marchini@stats.ox.ac.uk> and C Heaton <chrisheaton99@yahoo.com>}

\seealso{\code{\link{f.ica.fmri.gui}},\code{\link{f.plot.ica.fmri}} }

\keyword{utilities}
\eof
\name{f.ica.fmri.gui}
\alias{f.ica.fmri.gui}
\title{tcltk GUI to apply ICA to fMRI datasets}
\description{The GUI provides a quick and easy to use interface for
  applying spatial ICA to fMRI datasets. Computations are done in C for
  speed and low memory usage. 
}
\usage{
f.ica.fmri.gui()
}
\details{The user is required to enter the location of the fMRI dataset
  (stored in the ANALYZE format) and (optionally) a mask for the
  dataset. If no mask is supplied then an option to create mask is
  available. There is option to normalize the columns of the data matrix
  and to exclude the top and bottom slices (which are sometimes affected
  by the registration procedures).

Once completed, the user has the option of saving the results to an R
object or viewing the estimated components. The slices of each component
map are plotted sequentially in a grid followed by the components
associated time-course and that time-courses periodogram/power spectrum.}
\value{
  \item{User named R object (optional)}{Once completed, the user has the
    option of saving the results to an R object named by the user.}
}
\author{J L Marchini <marchini@stats.ox.ac.uk> and C Heaton <chrisheaton99@yahoo.com>}

\seealso{\code{\link{f.ica.fmri}},\code{\link{f.plot.ica.fmri}}}

\keyword{utilities}
\eof
\name{f.plot.ica.fmri}
\alias{f.plot.ica.fmri}
\title{Plots a specified component from the output of f.ica.fmri}
\description{Plots a specified component from the output of f.ica.fmri
}
\usage{
f.plot.ica.fmri(obj.ica, comp, cols)
}
\arguments{
  \item{obj.ica}{R object returned by the function f.ica.fmri}
  \item{comp}{number of the component to plot}
  \item{cols}{optional vector of colours to use for plotting}
}
\details{The slices of the specified component map are plotted
  sequentially in a grid followed by the components associated
  time-course and that time-courses periodogram/power spectrum
}
\author{J L Marchini <marchini@stats.ox.ac.uk> and C Heaton <chrisheaton99@yahoo.com>}

\seealso{\code{\link{f.ica.fmri}},\code{\link{f.ica.fmri.gui}}}

\keyword{utilities}

\eof
\name{f.plot.ica.fmri.jpg}
\alias{f.plot.ica.fmri.jpg}
\title{Plot the components of the ouput of f.ica.fmri to a series of
  jpeg files}
\description{This function allows the compact graphical storage of the
  output of a spatial ICA decomposition of an fMRI dataset. each
  component is plotted to a jpeg.
}
\usage{
f.plot.ica.fmri.jpg(ica.obj, file="./ica", cols=heat.colors(100), width=700, height=700)
}
\arguments{
  \item{ica.obj}{Object that is the output of f.ica.fmri}
  \item{file}{The component i will be plotted in file file.comp.i.jpeg}
  \item{cols}{Optional colour vector for plotting the components}
  \item{width}{Width of jpeg images}
  \item{height}{Height of jpeg images}
}
\author{J L Marchini}


\seealso{\code{\link{f.ica.fmri}},
  \code{\link{jpeg}}
}

\keyword{utilities}



 





















\eof
\name{f.read.analyze.header}
\alias{f.read.analyze.header}
\title{read Analyze header file}
\description{Reads the ANALYZE image format .hdr header file into a
  list.}
\usage{f.read.analyze.header(file)}
\arguments{\item{file}{The .hdr file to be read}}
\value{A list containing the information in the fields of the .hdr
  file. Only the ones considered useful are included. See comments
  included in the function definition if you want to extend the amount
  of information extracted and stored.
\item{swap}{TRUE or FALSE variable indicating whether files are big or little endian}
\item{file.name}{path name of the .img file}
\item{dim}{vector of image dimensions. The first entry specifies the number
  of dimensions}
\item{vox.units}{specifies the spatial units of measure for a voxel}
\item{cal.units}{specifies the name of the calibration unit i.e. pixel,voxel}
\item{datatype}{integer indicator of data storage type for each voxel}
\item{data.type}{character vector indicating data storage type for each voxel}
\item{bit.pix}{the number of bits per voxel}
\item{pixdim}{parallel vector to dim giving real world voxel unit measurements}
\item{glmax}{maximum voxel value}
\item{glmin}{minimum voxel value}}
\seealso{
  \code{\link{f.analyze.file.summary}}}
\examples{
f.read.analyze.header(system.file("example.hdr", package="AnalyzeFMRI"))
}
\keyword{utilities}



\eof
\name{f.read.analyze.slice}
\alias{f.read.analyze.slice}
\title{read one slice from a .img file}
\description{Reads in a specific slice from an ANALYZE .img image format
  file into an array.}
\usage{f.read.analyze.slice(file, slice, tpt)}
\arguments{
  \item{file}{The .img file to be read from}
  \item{slice}{The number of the slice (assumed to be the 3rd dimension)}
  \item{tpt}{The number of the scan that the slice is to be taken from}}
\details{The entire dataset is assumed to be 4D and a slice is extracted
  that is referenced by specifying the last two dimensions of the
  dataset i.e.slice and tpt.}
\value{An array containing the slice}
\seealso{
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.read.analyze.ts}},
  \code{\link{f.read.analyze.volume}}
 
}
\examples{
a<-f.read.analyze.slice(system.file("example.img", package="AnalyzeFMRI"),10,1)
dim(a)
}
\keyword{utilities}
\eof
\name{f.read.analyze.slice.at.all.timepoints}
\alias{f.read.analyze.slice.at.all.timepoints}

\title{reads a slice at all time points from a .img file}
\description{Reads in a slice of a .img file at all time points into an array}
\usage{f.read.analyze.slice.at.all.timepoints(file, slice)
}
\arguments{
  \item{file}{\code{file} The location of the .img file}
  \item{slice}{\code{slice} The number of the slice to be read in}
}
\value{An array containing the slice at all time points
}
\seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.ts}},
  \code{\link{f.read.analyze.volume}}   

}
\examples{
a<-f.read.analyze.slice.at.all.timepoints(system.file("example.img", package="AnalyzeFMRI"),10)
dim(a)
}
\keyword{utilities}
\eof
\name{f.read.analyze.tpt}
\alias{f.read.analyze.tpt}
\title{Read in a volume at one time point}
\description{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the 3D volume of measurements at a specific time point.}
\usage{f.read.analyze.tpt(file, tpt)}
\arguments{
  \item{file}{The .img file.} 
  \item{tpt}{The time point to read in.}}
\details{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the 3D volume of measurements at a specific time point.}
\value{A 3D array containing the volume.}\
seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.write.analyze}}, }
\examples{
f.read.analyze.tpt(system.file("example.img", package="AnalyzeFMRI"),1)
}
\keyword{utilities}
\eof
\name{f.read.analyze.ts}
\alias{f.read.analyze.ts}
\title{read in one voxel time series}
\description{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the time series from a specified position in 3D into a vector.}
\usage{f.read.analyze.ts(file, x, y, z)}
\arguments{
  \item{file}{The .img file}                 
  \item{x}{The x-coordinate}
  \item{y}{The y-coordinate}
  \item{z}{The z-coordinate}}
\details{Given a 4D ANALYZE .img/.hdr image pair this function can
  read in the time series from a specified position in 3D into a vector.}
\value{A vector containing the time series}
\seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.write.analyze}}, }
\examples{
f.read.analyze.ts(system.file("example.img", package="AnalyzeFMRI"),30,30,10)
}
\keyword{utilities}
\eof
\name{f.read.analyze.volume}
\alias{f.read.analyze.volume}
\title{read whole .img file}
\description{Reads the ANALYZE image format .img file into an array.}
\usage{f.read.analyze.volume(file)}
\arguments{\item{file}{The location of the .img file to be read}}
\value{An array with the appropriate dimensions containing the image
  volume. A print out of the file information is also given. The
  function assumes that the corresponding .hdr file is in the same
  directory as the .img file. }
\seealso{
  \code{\link{f.read.analyze.slice}},
  \code{\link{f.read.analyze.slice.at.all.timepoints}},
  \code{\link{f.read.analyze.ts}}
}
\examples{
a<-f.read.analyze.volume(system.file("example.img", package="AnalyzeFMRI"))
dim(a)
}
\keyword{utilities}

\eof
\name{f.spectral.summary}
\alias{f.spectral.summary}
\title{plots graphical summary of spectral properties of an fMRI dataset}
\description{For an analyze .img file the periodogram of the time series are divided by a flat spectral estimate using the median periodogram ordinate. The resulting values are then combined within each Fourier frequency and quantiles are plotted against frequency. This provides a fast look at a fMRI dataset to identify any artifacts that reside at single frequencies.
}
\usage{f.spectral.summary(file, mask.file, ret.flag=FALSE)}

\arguments{
  \item{file}{\code{file} The location of .img file  }
  \item{mask.file}{\code{mask.file} Optional location of a .img file
    containing a mask. If not given then one is created.}
  \item{ret.flag}{\code{ret.flag} flag specifying whether to return the
    array of quantiles at each frequency}
}
\value{If \code{ret.flag = TRUE} the an array of quantiles at each
  frequency is returned
}
\seealso{
  \code{\link{f.analyze.file.summary}}}     
\keyword{utilities}
\eof
\name{f.write.analyze}
\alias{f.write.analyze}
\title{writes an array to a .img/.hdr pair}
\description{Creates a .img and .hdr pair of files from a given array}
\usage{f.write.analyze(mat,file,size,pixdim,vox.units,cal.units)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, without .img or .hdr
    suffix}
  \item{size}{Specify the format of the .img file. Either "float" (for 4
    byte floats) or "int" (2 byte integers) or "char" (1 byte integers).}
  \item{pixdim}{A vector of length 3 specifying the voxel dimensions in
    mm}
  \item{vox.units}{String specifying the spatial units of measure for a
    voxel}
  \item{cal.units}{String specifying the name of calibration unit}
}

\value{Nothing is returned}
\seealso{
  \code{\link{f.write.array.to.img.8bit}},
  \code{\link{f.write.array.to.img.2bytes}},
  \code{\link{f.write.array.to.img.float}} }    
\examples{
a<-array(rnorm(20*30*40*3),dim=c(20,30,40,3))
file<-"temp"
f.write.analyze(a,file,size="float")
f.analyze.file.summary("temp.img")
}
\keyword{utilities}
\eof
\name{f.write.array.to.img.2bytes}
\alias{f.write.array.to.img.2bytes}
\title{write array of 2 byte integers}
\description{Writes an array to a .img file of 2 byte integers}
\usage{f.write.array.to.img.2bytes(mat,file)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, preferably with .img suffix}
}
\value{Nothing is returned}
\seealso{
  \code{\link{f.write.analyze}}
  \code{\link{f.write.array.to.img.float}}  }
\keyword{utilities}
\eof
\name{f.write.array.to.img.8bit}
\alias{f.write.array.to.img.8bit}
\title{write array of 1 byte integers}
\description{Writes an array to a .img file of 1 byte integers}
\usage{f.write.array.to.img.8bit(mat,file)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, preferably with .img suffix}
}
\value{Nothing is returned}
\seealso{
  \code{\link{f.write.analyze}},
  \code{\link{f.write.array.to.img.float}},
  \code{\link{f.write.array.to.img.2bytes}}  }
\keyword{utilities}
\eof
\name{f.write.array.to.img.float}
\alias{f.write.array.to.img.float}
\title{write array of 4 byte floats}
\description{Writes an array to a .img file of 4 byte floats}
\usage{f.write.array.to.img.float(mat,file)}
\arguments{\item{mat}{An array}
  \item{file}{The name of the file to be written, preferably with .img
    suffix}}
 \seealso{
  \code{\link{f.write.analyze}},
  \code{\link{f.write.array.to.img.2bytes}} ,
  \code{\link{f.write.array.to.img.8bit}}   }
\value{Nothing is returned}
\keyword{utilities}
\eof
\name{f.write.list.to.hdr}
\alias{f.write.list.to.hdr}
\title{writes a .hdr file}
\description{Writes a list of attributes to a .hdr file}
\usage{f.write.list.to.hdr(L,file)}
\arguments{\item{L}{A list of the all the fields included in a .hdr file}
  \item{file}{The name of the file to write, preferably with .hdr suffix}}
\value{Nothing is returned}
\seealso{
   \code{\link{f.basic.hdr.list.create}}    } 
 \examples{
a<-array(rnorm(20*30*40*3),dim=c(20,30,40,3))
file<-"temp.hdr"
b<-f.basic.hdr.list.create(a, file)
f.basic.hdr.list.create(b,file)}
\keyword{utilities}
\eof
